@@ -29,7 +29,6 @@ class Type:
     overload = TypeAnnotation("overload")
     none = TypeConstant(None)
     str = TypeClass(str)
-    Set = TypeAnnotation("Set")
     bool = TypeClass(bool)
     bytes = TypeClass(bytes)
     bytearray = TypeClass(bytearray)
@@ -48,6 +47,7 @@ class Type:
     DictStrAny = TypeSubscript(Dict, [str, Any])
     DictStrStr = TypeSubscript(Dict, [str, str])
     IOBytes = TypeSubscript(IO, [bytes])
+    IOAny = TypeSubscript(IO, [Any])
     RemoveArgument = RemoveArgument()
     NotRequired = TypeAnnotation("NotRequired")
 
